"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ScanService = void 0;
var context_map_server_client_1 = require("../infrastructure/client/context-map-server.client");
var scan_1 = require("../model/scan");
var resource_service_1 = require("./resource.service");
var technology_stack_service_1 = require("./technology-stack.service");
var actor_service_1 = require("./actor.service");
var ts_morph_1 = require("ts-morph");
var subscribed_endpoint_service_1 = require("./subscribed-endpoint.service");
var languages_service_1 = require("./languages.service");
var glossary_service_1 = require("./glossary.service");
var entity_service_1 = require("./entity.service");
var ScanService = /** @class */ (function () {
    function ScanService(parameters) {
        this.parameters = parameters;
        this.project = new ts_morph_1.Project();
        this.client = new context_map_server_client_1.ContextMapServerClient(parameters);
        this.resourceService = new resource_service_1.ResourceService();
        this.technologyStackService = new technology_stack_service_1.TechnologyStackService();
        // this.decoratorService = new DecoratorService(this.project)
        this.actorService = new actor_service_1.ActorService(this.project);
        this.glossaryService = new glossary_service_1.GlossaryService(this.project);
        this.entityService = new entity_service_1.EntityService(this.project);
        this.subscribedEndpointService = new subscribed_endpoint_service_1.SubscribedEndpointService(this.project);
        this.languageService = new languages_service_1.LanguagesService(this.project);
    }
    ScanService.prototype.scan = function () {
        var scan = this.initializeScan();
        this.scanConfiguration(scan);
        this.scanTechStack(scan);
        this.scanActors(scan);
        this.scanSubscribedEndpoints(scan);
        this.scanBytesOfCode(scan);
        this.scanGlossaryTerms(scan);
        this.scanEntities(scan);
        // this.scanDecorators(scan)
        this.sendScan(scan);
    };
    ScanService.prototype.initializeScan = function () {
        console.log('Scanning sources at: ' + this.parameters.source);
        this.project.addSourceFilesAtPaths(this.parameters.source);
        return (0, scan_1.createScan)();
    };
    ScanService.prototype.scanConfiguration = function (scan) {
        var configurationResource = this.resourceService.scanConfiguration();
        scan.execution.scannedProperties = true;
        scan.execution.scannedSystem = true;
        if (this.parameters.componentName != null && this.parameters.componentName.length > 0) {
            scan.scannedComponent.name = this.parameters.componentName;
        }
        else {
            scan.scannedComponent.name = configurationResource.getName();
        }
        if (this.parameters.systemName != null && this.parameters.systemName.length > 0) {
            scan.scannedComponent.systemName = this.parameters.systemName;
        }
        else {
            scan.scannedComponent.systemName = configurationResource.getSystemName();
        }
        scan.scannedComponent.version = configurationResource.getVersion();
        scan.scannedComponent.team = configurationResource.getTeam();
        scan.scannedComponent.domainVisionStatement = configurationResource.getDomainVisionStatement();
        scan.scannedComponent.type = configurationResource.getComponentType();
        scan.scannedComponent.urlBuildPipeline = configurationResource.getUrlBuildPipeline();
        scan.scannedComponent.urlDocumentation = configurationResource.getUrlDocumentation();
        scan.scannedComponent.urlIssueManagement = configurationResource.getUrlIssueManagement();
        scan.scannedComponent.urlVersionControl = configurationResource.getUrlVersionControl();
    };
    // private scanDecorators(scan: Scan): void {
    //   console.info("Scanning entities");
    //   scan.execution.scannedEntities = true;
    //   scan.entities = this.decoratorService.scan();
    //   console.info(" < Found " + scan.entities.length + " entities");
    // }
    ScanService.prototype.scanBytesOfCode = function (scan) {
        console.info("Scanning bytes of code");
        scan.execution.scannedBytesOfCode = true;
        scan.scannedComponent.bytesOfCodes = this.languageService.getBytesOfCodePerLanguage();
        console.info(" < Found " + scan.scannedComponent.bytesOfCodes.length + " languages");
    };
    ScanService.prototype.scanGlossaryTerms = function (scan) {
        console.info("Scanning glossary terms");
        scan.execution.scannedGlossary = true;
        scan.glossaryTerms = this.glossaryService.scan();
        console.info(" < Found " + scan.glossaryTerms.length + " glossary terms");
    };
    ScanService.prototype.scanEntities = function (scan) {
        console.info("Scanning entities");
        scan.execution.scannedEntities = true;
        scan.entities = this.entityService.scan();
        console.info(" < Found " + scan.entities.length + " entities");
    };
    ScanService.prototype.scanSubscribedEndpoints = function (scan) {
        console.info("Scanning subscribed endpoints");
        scan.execution.scannedSubscribedEndpoints = true;
        scan.subscribedEndpoints = this.subscribedEndpointService.scan();
        console.info(" < Found " + scan.subscribedEndpoints.length + " subscribed endpoints");
    };
    ScanService.prototype.scanActors = function (scan) {
        console.info("Scanning actors");
        scan.execution.scannedActors = true;
        scan.actors = this.actorService.scan();
        console.info(" < Found " + scan.actors.length + " actors");
    };
    ScanService.prototype.scanTechStack = function (scan) {
        console.info("Scanning techstack");
        scan.execution.scannedTechnologies = true;
        scan.scannedComponent.technologies = this.technologyStackService.scan();
        console.info(" < Found " + scan.scannedComponent.technologies.length + " technologies");
    };
    ScanService.prototype.sendScan = function (scan) {
        return this.client.processScan(scan);
    };
    return ScanService;
}());
exports.ScanService = ScanService;
